network_path: Create a Path to the QSP Network Drive

Description Usage Arguments Details Value Examples

View source: R/network_path.R

Description

This function creates a path to the QSP directory on the network drive. It will automatically determine if the local machine runs Windows or MacOS, and set the appropriate start of the network path. This is not yet set up for Linux machines.

Usage

1
2
3
4
network_path(
  windows_path = fs::path("R:"),
  mac_path = fs::path("/Volumes", "Research")
)

Arguments

windows_path

The path to use on Windows machines.

mac_path

The path to use on Macs.

Details

This function will create the path object. To use it, you must either be on the Brown network or VPN into it.

Value

a fs::path() object

Examples

1
2
my_path <- network_path()
my_project <- fs::path(network_path(), "Projects", "My_Project")

dougtommet/QSPworkflow documentation built on Feb. 22, 2020, 12:19 a.m.