Description Usage Arguments Details Value Examples
This function creates a path to the QSP directory on the network drive. It will automatically determine if the local machine runs Windows or MacOS, and set the appropriate start of the network path. This is not yet set up for Linux machines.
1 2 3 4 | network_path(
windows_path = fs::path("R:"),
mac_path = fs::path("/Volumes", "Research")
)
|
windows_path |
The path to use on Windows machines. |
mac_path |
The path to use on Macs. |
This function will create the path object. To use it, you must either be on the Brown network or VPN into it.
a fs::path() object
1 2 | my_path <- network_path()
my_project <- fs::path(network_path(), "Projects", "My_Project")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.